<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../../forms/fontdialog.ui" line="14"/>
        <location filename="../../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Vybrat písmo terminálu</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Písmo:</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Close Tab</source>
        <translation type="vanished">Zavřít kartu</translation>
    </message>
    <message>
        <source>Split Terminal Horizontally</source>
        <translation type="vanished">Rozdělit terminál vodorovně</translation>
    </message>
    <message>
        <source>Split Terminal Vertically</source>
        <translation type="vanished">Rozdělit terminál svisle</translation>
    </message>
    <message>
        <source>Collapse Subterminal</source>
        <translation type="vanished">Složit podterminál</translation>
    </message>
    <message>
        <source>Next Subterminal</source>
        <translation type="vanished">Další podterminál</translation>
    </message>
    <message>
        <source>Previous Subterminal</source>
        <translation type="vanished">Předchozí podterminál</translation>
    </message>
    <message>
        <source>Next Tab</source>
        <translation type="vanished">Další karta</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="79"/>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation type="vanished">Přejmenovat sezení</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="171"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Stiskněte &quot;%1&quot; pro zobrazení terminálu.</translation>
    </message>
    <message>
        <source>Clear Current Tab</source>
        <translation type="vanished">Vyprázdnit nynější kartu</translation>
    </message>
    <message>
        <source>Previous Tab</source>
        <translation type="vanished">Předchozí karta</translation>
    </message>
    <message>
        <source>Move Tab Left</source>
        <translation type="vanished">Přesunout kartu vlevo</translation>
    </message>
    <message>
        <source>Move Tab Right</source>
        <translation type="vanished">Přesunout kartu vpravo</translation>
    </message>
    <message>
        <source>Copy Selection</source>
        <translation type="vanished">Kopírovat výběr</translation>
    </message>
    <message>
        <source>Paste Clipboard</source>
        <translation type="vanished">Vložit schránku</translation>
    </message>
    <message>
        <source>Paste Selection</source>
        <translation type="vanished">Vložit výběr</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="vanished">Přiblížit</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="vanished">Oddálit</translation>
    </message>
    <message>
        <source>Zoom reset</source>
        <translation type="vanished">Nastavit znovu zvětšení</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation type="vanished">Hledat...</translation>
    </message>
    <message>
        <source>Save Session</source>
        <translation type="vanished">Uložit sezení</translation>
    </message>
    <message>
        <source>Load Session</source>
        <translation type="vanished">Nahrát sezení</translation>
    </message>
    <message>
        <source>Toggle Menu</source>
        <translation type="vanished">Přepnout nabídku</translation>
    </message>
    <message>
        <source>New Tab</source>
        <translation type="vanished">Nová karta</translation>
    </message>
    <message>
        <source>New Window</source>
        <translation type="vanished">Nové okno</translation>
    </message>
    <message>
        <source>Hide Window Borders</source>
        <translation type="vanished">Skrýt okraje okna</translation>
    </message>
    <message>
        <source>Show Tab Bar</source>
        <translation type="vanished">Ukázat pruh s kartami</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="vanished">Dole</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="vanished">Nahoře</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">Vpravo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">Vlevo</translation>
    </message>
    <message>
        <source>Tabs Layout</source>
        <translation type="vanished">Rozvržení karet</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Žádné</translation>
    </message>
    <message>
        <source>Scrollbar Layout</source>
        <translation type="vanished">Posunovatelné rozvržení</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="211"/>
        <source>&amp;Clear Active Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="218"/>
        <source>&amp;Next Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="221"/>
        <source>&amp;Previous Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="224"/>
        <source>Move Tab &amp;Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="227"/>
        <source>Move Tab &amp;Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="232"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="235"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="240"/>
        <source>&amp;Collapse Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="243"/>
        <source>&amp;Top Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="246"/>
        <source>&amp;Bottom Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="249"/>
        <source>L&amp;eft Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="252"/>
        <source>R&amp;ight Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="259"/>
        <source>Copy &amp;Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Paste Clip&amp;board</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="265"/>
        <source>Paste S&amp;election</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="268"/>
        <source>Zoom &amp;in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="271"/>
        <source>Zoom &amp;out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="274"/>
        <source>Zoom rese&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="279"/>
        <source>&amp;Find...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="287"/>
        <source>&amp;Save Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="293"/>
        <source>&amp;Load Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="300"/>
        <source>&amp;Toggle Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="305"/>
        <source>Rename session</source>
        <translation type="unfinished">Přejmenovat sezení</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="313"/>
        <source>&amp;New Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="317"/>
        <source>New Tab From &amp;Preset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="318"/>
        <source>1 &amp;Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="320"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="322"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="324"/>
        <source>4 Terminal&amp;s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="330"/>
        <source>&amp;Close Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="333"/>
        <source>&amp;New Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="338"/>
        <source>&amp;Preferences...</source>
        <translation type="unfinished">&amp;Nastavení...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="342"/>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Ukončit</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="348"/>
        <source>&amp;Hide Window Borders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="359"/>
        <source>&amp;Show Tab Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="367"/>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="373"/>
        <source>Toggle Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="381"/>
        <source>&amp;Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="382"/>
        <source>&amp;Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="383"/>
        <location filename="../../mainwindow.cpp" line="419"/>
        <source>&amp;Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="384"/>
        <location filename="../../mainwindow.cpp" line="420"/>
        <source>&amp;Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="402"/>
        <source>&amp;Tabs Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="418"/>
        <source>&amp;None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="436"/>
        <source>S&amp;crollbar Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="449"/>
        <source>&amp;BlockCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="450"/>
        <source>&amp;UnderlineCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="451"/>
        <source>&amp;IBeamCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="468"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="558"/>
        <source>Exit QTerminal</source>
        <translation>Ukončit QTerminal</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="560"/>
        <source>Do not ask again</source>
        <translation>Neptat se znovu</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="568"/>
        <source>Are you sure you want to exit?</source>
        <translation>Jste si jistý, že chcete program ukončit?</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="598"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>Lehký emulátor terminálu</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <source>QTerminal Properties</source>
        <translation type="vanished">Vlastnosti QTerminal</translation>
    </message>
    <message>
        <source>Terminal Font</source>
        <translation type="vanished">Písmo terminálu</translation>
    </message>
    <message>
        <source>Look and Feel</source>
        <translation type="vanished">Vzhled</translation>
    </message>
    <message>
        <source>History</source>
        <translation type="vanished">Historie</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="432"/>
        <source>Emulation</source>
        <translation>Emulace</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="62"/>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="52"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="57"/>
        <location filename="../../forms/propertiesdialog.ui" line="457"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="67"/>
        <source>Dropdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="72"/>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="90"/>
        <source>Hide tab bar with only one tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="100"/>
        <source>Color scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="110"/>
        <source>Scrollbar position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="120"/>
        <source>Start with preset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="136"/>
        <source>Show a border around the current terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="143"/>
        <source>Terminal transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="153"/>
        <source>Application transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="164"/>
        <source>None (single terminal)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="169"/>
        <source>2 terminals horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="174"/>
        <source>2 terminals vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="179"/>
        <source>4 terminals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="218"/>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="254"/>
        <source>&amp;Change...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="267"/>
        <source>Tabs position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="296"/>
        <source>Widget style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="319"/>
        <source>Show the menu bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="326"/>
        <source>Keyboard cursor shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="336"/>
        <source>Change window title based on current terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="343"/>
        <source>Change window icon based on current terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="350"/>
        <source>Enable bi-directional text support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="357"/>
        <source>Background image:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="369"/>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="378"/>
        <source>Show terminal size on resize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="385"/>
        <source>Limit tab width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="395"/>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="405"/>
        <source>Show close button on each tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="441"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="463"/>
        <source>Action after paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="473"/>
        <source>Confirm multiline paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="480"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="513"/>
        <source>Open new terminals in current working directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="520"/>
        <source>Save Size when closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="527"/>
        <source>Save Position when closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="534"/>
        <source>Ask for confirmation when closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="544"/>
        <source>Unlimited history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="551"/>
        <source>History size (in lines)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="558"/>
        <source>Default $TERM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="572"/>
        <source>xterm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="577"/>
        <source>xterm-256color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="649"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="659"/>
        <location filename="../../forms/propertiesdialog.ui" line="676"/>
        <source>%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="666"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="722"/>
        <source>Edit bookmark file contents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="744"/>
        <source>Enable bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="753"/>
        <source>Bookmark file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Set Font...</source>
        <translation type="vanished">&amp;Nastavit písmo...</translation>
    </message>
    <message>
        <source>Action after paste clipboard</source>
        <translation type="vanished">Činnost po vložení obsahu schránky</translation>
    </message>
    <message>
        <source>Color Scheme:</source>
        <translation type="vanished">Schéma barev:</translation>
    </message>
    <message>
        <source>GUI Style:</source>
        <translation type="vanished">Styl rozhraní:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="631"/>
        <source>Show on start</source>
        <translation>Ukázat při spuštění</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="638"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Height %:</source>
        <translation type="vanished">Výška %:</translation>
    </message>
    <message>
        <source>Width %:</source>
        <translation type="vanished">Šířka %:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="690"/>
        <source>Shortcut:</source>
        <translation>Klávesová zkratka:</translation>
    </message>
    <message>
        <source>Edit File Content</source>
        <translation type="vanished">Upravit obsah souboru</translation>
    </message>
    <message>
        <source>Use Bookmarks</source>
        <translation type="vanished">Použít záložky</translation>
    </message>
    <message>
        <source>Bookmark FIle:</source>
        <translation type="vanished">Soubor se záložkami:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="766"/>
        <source>Find...</source>
        <translation>Hledat...</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="775"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tabs Position:</source>
        <translation type="vanished">Poloha karet:</translation>
    </message>
    <message>
        <source>&amp;Application Transparency:</source>
        <translation type="vanished">Průhlednost p&amp;rogramu:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="187"/>
        <location filename="../../forms/propertiesdialog.ui" line="280"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <source>Terminal Transparency:</source>
        <translation type="vanished">Průhlednost &amp;terminálu:</translation>
    </message>
    <message>
        <source>Show Main Menu</source>
        <translation type="vanished">Ukázat hlavní nabídku</translation>
    </message>
    <message>
        <source>Always Show Tabs</source>
        <translation type="vanished">Vždy ukázat karty</translation>
    </message>
    <message>
        <source>Limited to: </source>
        <translation type="vanished">Omezeno na:</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation type="vanished">Bez omezení</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="614"/>
        <source>Shortcut</source>
        <translation>Klávesová zkratka</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="619"/>
        <source>Key</source>
        <translation>Klávesa</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <source>No scrollbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>BlockCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>UnderlineCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>IBeamCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>No move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>Move start</source>
        <translation>Přesunout začátek</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>Move end</source>
        <translation>Přesunout konec</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="129"/>
        <location filename="../../propertiesdialog.cpp" line="199"/>
        <source>System Default</source>
        <translation>Výchozí nastavení systému</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="282"/>
        <source>Choose a background image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="283"/>
        <source>Images (*.bmp *.png *.xpm *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="348"/>
        <source>Open or create bookmarks file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../../termwidget.cpp" line="237"/>
        <source>Show Details...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../bookmarkswidget.cpp" line="110"/>
        <source>Local Bookmarks</source>
        <translation>Místní záložky</translation>
    </message>
    <message>
        <location filename="../../bookmarkswidget.cpp" line="168"/>
        <source>Synchronized Bookmarks</source>
        <translation>Seřízené záložky</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../../tabwidget.cpp" line="73"/>
        <location filename="../../tabwidget.cpp" line="219"/>
        <source>Shell No. %1</source>
        <translation>Shell číslo %1</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="187"/>
        <source>Tab name</source>
        <translation>Název karty</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="188"/>
        <source>New tab name:</source>
        <translation>Nové název karty:</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="208"/>
        <source>Select new tab title color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="229"/>
        <source>Close session</source>
        <translation>Zavřít sezení</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="231"/>
        <source>Change title color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename session</source>
        <translation type="vanished">Přejmenovat sezení</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../../termwidgetholder.cpp" line="78"/>
        <source>Load Session</source>
        <translation>Nahrát sezení</translation>
    </message>
    <message>
        <location filename="../../termwidgetholder.cpp" line="79"/>
        <source>List of saved sessions:</source>
        <translation>Seznam uložených sezení:</translation>
    </message>
</context>
<context>
    <name>TermWidgetImpl</name>
    <message>
        <source>Split Terminal Horizontally</source>
        <translation type="obsolete">Rozdělit Terminál Horizontálně</translation>
    </message>
    <message>
        <location filename="../../termwidget.cpp" line="229"/>
        <source>Paste multiline text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../termwidget.cpp" line="230"/>
        <source>Are you sure you want to paste this text?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Hlavní okno</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Soubor</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="vanished">Činnosti</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Nápověda</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">Pohled</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="vanished">Úpravy</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="vanished">&amp;Ukončit</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">O programu...</translation>
    </message>
    <message>
        <source>About Qt...</source>
        <translation type="vanished">O Qt...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation type="vanished">&amp;Nastavení...</translation>
    </message>
</context>
</TS>
